************************************************************************************
* rin_newey_multeqn.do
*
* Multiple equation constrained OLS with NW SEs, full covariances allowed 
* across equations
*  equations: 1,...,nv
*  structure hard wired for common lagged vbles used in RIN project
*  allows fully interacted variables
************************************************************************************
if "$t0"=="01Jan2013" local nt0=1823
if "$t0"=="01Feb2013" local nt0=1844
if "$tn"=="31Dec2013" local ntn=2075
if "$t0"=="01Jan2014" local nt0=2076
if "$tn"=="10Feb2015" local ntn=2354
if "$tn"=="10Mar2015" local ntn=2373
*local nt0 = snt0
*local ntn = sntn
local nv = snv
local p = splags
local nw = snw
 local pm1 = `p'-1
 local pp1 = `p'+1
* create x's 
forvalues j = 1/`nv' {
 forvalues h = 0/`pm1' {
  cap drop x`j'`h'
  qui gen x`j'`h' = L`h'.dxvar1
 }
 cap drop x`j'`p'
 qui gen x`j'`p' = L`p'.xvar1
}
* Project out variable-specific coefficients
forvalues j = 1/`nv' {
 forvalues h = 0/`p' {
  qui reg x`j'`h' $intvars in `nt0'/`ntn'
  qui cap drop e99
  qui predict e99, resid
  qui replace x`j'`h' = e99
 }
 qui reg y`j' $intvars in `nt0'/`ntn'
 qui cap drop e99 
 qui cap drop y`j'dm
 qui cap predict e99, resid
 qui gen y`j'dm = e99
}
* create moment matrices
mat mxx = J(`pp1',`pp1',0)
mat mxy = J(`pp1',1,0)
forvalues j = 1/`nv' {
 forvalues h = 0/`p' {
  qui corr x`j'`h' y`j'dm in `nt0'/`ntn', cov
  mat mxy[`h'+1,1] = mxy[`h'+1,1] + r(cov_12)*(r(N)-1)
  forvalues k = 0/`p' {
   qui corr x`j'`h' x`j'`k' in `nt0'/`ntn', cov
   mat mxx[`h'+1,`k'+1] = mxx[`h'+1,`k'+1] + r(cov_12)*(r(N)-1)
  }
 }
}
* OLSE, resids, and x*e terms
mat bhatolsc = inv(mxx)*mxy
*mat list bhatolsc
forvalues j = 1/`nv' {
 cap drop e`j'
 qui gen e`j' = y`j'dm
 forvalues h = 0/`p' {
  qui replace e`j' = e`j' - bhatolsc[`h'+1,1]*x`j'`h'
 }
 cap drop z`j'*
 forvalues h = 0/`p' {
  qui gen z`j'`h' = e`j'*x`j'`h'
 }
}
* NW "numerator" matrix
mat vv = J(`pp1',`pp1',0)
forvalues i = 1/`nv' {
 forvalues j = 1/`nv' {
  forvalues h = 0/`p' {
   forvalues k = 0/`p' {
    forvalues m = -`nw'/`nw' {
     sca wt = 1 - abs(`m'/(`nw'+1))
     qui replace e99 = z`j'`k'[_n-`m']
     *dis `i' "  " `j' "  " `h' "  " `k' "  " `m' "   " wt
     qui corr z`i'`h' e99 in `nt0'/`ntn', cov
     mat vv[`h'+1,`k'+1] = vv[`h'+1,`k'+1] + wt*r(cov_12)*(r(N)-1)
    }
   }
  }
 }
}
* variance matrix and SEs
mat om = inv(mxx)*vv*inv(mxx)
mat sebhatolsc = J(`pp1',1,0)
forvalues h = 0/`p' {
 mat sebhatolsc[`h'+1,1] = sqrt(om[`h'+1,`h'+1])
 dis `h'+1 "," bhatolsc[`h'+1,1] "," sebhatolsc[`h'+1,1]
}
* output to excel
local row = srow
local rp1 = `row'+1
/* unformatted
putexcel A`row'=("$slabel") B`row'=(`nv') C`row'=("$t0") D`row'=("$tn") E`row'=(`nw') F`row'=("$intvars") ///
         G`row'=matrix(bhatolsc') G`rp1'=matrix(sebhatolsc') using $outxls, modify
*/
* formatted
putexcel A`row'=("$slabel") B`row'=(`nv') C`row'=("$t0") D`row'=("$tn") E`row'=(`nw') F`row'=("$intvars") using $outxls, modify
local mm = rowsof(bhatolsc)
forvalues i = 1/`mm' {
 sca t99 = abs(bhatolsc[`i',1]/sebhatolsc[`i',1])
 local fb = string(bhatolsc[`i',1],"%5.3f")
  if t99>=1.645 local fb=string(bhatolsc[`i',1],"%5.3f") + "*"
  if t99>=1.96  local fb=string(bhatolsc[`i',1],"%5.3f") + "**"
  if t99>=2.575 local fb=string(bhatolsc[`i',1],"%5.3f") + "***"
 local fse = "(" + string(sebhatolsc[`i',1],"%5.3f") + ")"
 local xcol = char(70+`i')
 putexcel `xcol'`row'=("`fb'") `xcol'`rp1'=("`fse'") using $outxls, modify
}
sca srow = srow+2
