clear
cap log close
cap program drop _all
log using rin_passthru_dl.txt, text replace
set scheme s1color
set more off
************************************************************************************
* rin_passthru_dl.do              This version: 7/1/15
*
* RIN-fuel price analysis for Knittel-Meiselman-Stock paper
* Distributed lag regressions: Appendix tables
*
* Data misc.
*   weekdays: 0 = Sunday, 1 = Monday, etc. 
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup_wp
local runsfx "_vwp_$dset"
*
*------------------------------------------------------*
*         SAMPLE
global t0 "01Jan2013"
global t1 "31Dec2013"
global t2 "01Jan2014"
*global tn "31Dec2014"
global tn "10Mar2015"
*
local tsfx _$t0-$tn
local sfx "_condensed"
*------------------------------------------------------*
*
*------------------------------------------------------*
*    Summary statistics table, additional data description
*------------------------------------------------------*
*
foreach y in $diesel_sprdvars $bob_sprdvars e85_e10 e10b obc e85_e10t {
 qui su `y'i if (date>=td($t0))*(date<=td($tn))
 dis "`y'," %5.3f r(mean) "," %5.3f r(sd) "," %5.3f r(min) "," %5.3f r(max)
}
tsset date
gen dieselgu_jetgui_oa = dieselgu_jetgui if(dieselgu_jetgui>-.2)
local yy dieselgu_jetgui_oa
local yy rbobnyf_brenti
reg `yy' $savars
 predict `yy'_seas
 su `yy'_seas
tsset time
*
*------------------------------------------------------*
*         REGRESSIONS: daily
*------------------------------------------------------*
* specify lags for NW SEs - depends on levels or differences
local nwd = 15
*
foreach m in r i 5 {
 gen e10`m' = e10b`m'
 replace e10bt`m' = d6c`m'
 gen d5brentgale`m' = brentgale`m' - L5.brentgale`m'
}
*
foreach y in $diesel_sprdvars $bob_sprdvars e85_e10 e10b  {
 foreach m in r i 5 {
  gen d5`y'`m' = `y'`m' - L5.`y'`m'
  gen d5`y't`m' = `y't`m' - L5.`y't`m'
 }
*
global tabout "$tablepath `y'`tsfx'`sfx'`runsfx'.xls" 
dis "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
dis "     `y'    $tabout
dis "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
* -------- 5-day differences (end of week prices) ------------------		  
local m "i"
* (1) (D5i-1)
 newey d5`y'`m' d5`y't`m' $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
  outreg2 using "$tabout", ctitle("D5-SA") replace excel dec(3) nonotes addtext("Sample","Full")  ///
          drop($savars) adds("Sum of coeffs",_b[d5`y't`m'],"se",_se[d5`y't`m'], ///
  		  "F (seasonals)",`fsa',"p-val (seas)",`psa') nocon
* (2) (D5i-4)
 newey d5`y'`m' d5`y't`m' L5.d5`y't`m' $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
  testparm L5.d5`y't`m' 
   local fall = r(F)
   local pall = r(p)
  lincom d5`y't`m'+L5.d5`y't`m'
  outreg2 using "$tabout", ctitle("D5-SA") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop( $savars) adds("Sum of coeffs",r(estimate),"se",r(se), ///
		  "F (seasonals)",`fsa',"p-val (seas)",`psa',"F (lags)",`fall',"p-val (lags)",`pall') nocon
* (3) (D5i-6)
 newey d5`y'`m' d5`y't`m' L5.d5`y't`m' d5brentgale`m' L5.d5brentgale`m' $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
  testparm d5brentgale`m' L5.d5brentgale`m' 
   local fb = r(F)
   local pb = r(p)
  testparm L5.d5`y't`m' 
   local fall = r(F)
   local pall = r(p)
  lincom d5`y't`m'+L5.d5`y't`m'
  outreg2 using "$tabout", ctitle("D5-Brent-SA") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop($savars d5brentgale`m' L5.d5brentgale`m') adds("Sum of coeffs",r(estimate),"se",r(se), ///
		  "F (seasonals)",`fsa',"p-val (seas)",`psa',"F (Brent)",`fb',"p (Brent)",`pb', ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
* (4) (D5i-2)
 newey d5`y'`m' d5`y't`m' if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D5") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop( d5brentgale`m') adds("Sum of coeffs",_b[d5`y't`m'],"se",_se[d5`y't`m']) nocon
*
* -------- Daily first differences ------------------		  
* (5) (D-2)
 newey D.`y'r L(0/15).D.`y'ti $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D-SA") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop( $savars L(11/15).D.D.`y'ti L15.D.`y'ti) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (seasonals)",`fsa',"p-val (seas)",`psa', ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
* (6) (D-5)
 newey D.`y'r L(0/15).D.`y'ti L(0/5).D.brentei $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
  testparm L(0/5).D.brentei
   local fb = r(F)
   local pb = r(p)
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti L(0/5).D.brentei $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D-Brent") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop($savars L(11/15).D.D.`y'ti L15.D.`y'ti L(0/5).D.brentei) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (seasonals)",`fsa',"p-val (seas)",`psa', ///
		  "F (Brent)",`fb',"p (Brent)",`pb', ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
/*
 newey D.`y'r L(0/15).D.`y'ti L(0/5).D.brentei $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
  testparm L(0/5).D.brentei
   local fb = r(F)
   local pb = r(p)
  testparm $savars 
   local fsa = r(F)
   local psa = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti L(0/5).D.brentei $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D-Brent") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop($savars L(0/5).D.brentei L(11/15).D.D.`y'ti L15.D.`y'ti) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (seasonals)",`fsa',"p-val (seas)",`psa', ///
		  "F (Brent)",`fb',"p (Brent)",`pb', ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
*/
* (7) (D-1)
 newey D.`y'r L(0/15).D.`y'ti if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D") append excel dec(3) nonotes addtext("Sample","Full") ///
          drop( L(11/15).D.D.`y'ti L15.D.`y'ti) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
*
* --------------- 2013 ----------
* (8) (D5i-1)
 newey d5`y'`m' d5`y't`m' if (date>=td($t0))*(date<=td($t1)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D5") append excel dec(3) nonotes addtext("Sample","2013") ///
          adds("Sum of coeffs",_b[d5`y't`m'],"se",_se[d5`y't`m']) nocon
* (9) (D-1)
 newey D.`y'r L(0/15).D.`y'ti if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti if (date>=td($t0))*(date<=td($t1)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D") append excel dec(3) nonotes addtext("Sample","2013") ///
          drop( L(11/15).D.D.`y'ti L15.D.`y'ti) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
*
* --------------- 2014 ----------
* (10) (D5i-1)
 newey d5`y'`m' d5`y't`m' if (date>=td($t2))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D5") append excel dec(3) nonotes addtext("Sample","2014-15") ///
          adds("Sum of coeffs",_b[d5`y't`m'],"se",_se[d5`y't`m']) nocon

* (11) (D-1)
 newey D.`y'r L(0/15).D.`y'ti if (date>=td($t0))*(date<=td($tn)), lag(`nwd') force
  testparm L(1/15).D.`y'ti
   local fall = r(F)
   local pall = r(p)
  testparm L(11/15).D.`y'ti
   local f5 = r(F)
   local p5 = r(p)
 newey D.`y'r L(0/14).D.D.`y'ti L15.D.`y'ti if (date>=td($t2))*(date<=td($tn)), lag(`nwd') force
  outreg2 using "$tabout", ctitle("D") append excel dec(3) nonotes addtext("Sample","2014-15") ///
          drop( L(11/15).D.D.`y'ti L15.D.`y'ti) adds("Sum of coeffs",_b[L15.D.`y'ti],"se",_se[L15.D.`y'ti], ///
		  "F (lags)",`fall',"p-val (lags)",`pall') nocon
		  }
log close
end
