clear
cap log close
cap program drop _all
log using rin_passthru_figs_wp.txt, text replace
set scheme s1color
set more off
************************************************************************************
* rin_passthru_figs_wp.do
*
* RIN-fuel price analysis for Knittel-Meiselman-Stock paper
*
* Figures - note this generates multiple figures, only a subset are presented in the paper
*
* Data misc.
*   weekdays: 0 = Sunday, 5 = Friday
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup_wp
local runsfx "_vwp_$dset"
*------------------------------------------------------*
*         SAMPLE
* Sample $t0 - $tn
global t0 "01Jan2013"
global t1 "31Dec2013"
global t2 "01Jan2014"
global t3 "01Feb2015"
global tn "10Mar2015"
global tsfx "$t0-$tn`runsfx'"
*------------------------------------------------------*
*
*------------------------------------------------------*
*    Time series plots for multiple spreads
*------------------------------------------------------*
*
label var obci "Petroleum RIN obligation"
global diesellist dieselgu_jetgui dieselny_dieselroti dieselgu_dieselroti 
 label var dieselgu_jetgui "Gulf diesel-jet fuel spread"
 label var dieselny_dieselroti "NY-Rotterdam diesel spread"
 label var dieselgu_dieselroti "Gulf-Rotterdam diesel spread"
*
global boblist rbobnyf_ebobi rbobnyf_brenti rbobla_brenti 
 label var rbobnyf_ebobi "NY RBOB-EBOB spread"
 label var rbobnyf_brenti "NY RBOB-Brent spread"
 label var rbobla_brenti "LA RBOB-Brent spread"
*
global retaillist e85_e10i
 label var e85_e10i "E85-E10 spread"
*
tsset date
twoway (tsline $diesellist, yaxis(1)) (tsline obci, yaxis(2)) if tin($t0,$tn), ///
  title("Wholesale diesel price spreads and petroleum RIN obligation") ///
  ytitle("spreads: $ per gallon") xtitle("RIN obligation: $ per gallon") ///
  subtitle("Spreads, left scale; RIN obligation, right scale")
  global a98 "figs\dieselspreads_$tsfx.emf"
  graph export $a98, replace
*
twoway (tsline $boblist, yaxis(1)) (tsline obci, yaxis(2)) if tin($t0,$tn), ///
  title("Wholesale BOB price spreads and petroleum RIN obligation") ///
  ytitle("spreads: $ per gallon") xtitle("RIN obligation: $ per gallon") ///
  subtitle("Spreads, left scale; RIN obligation, right scale")
  global a98 "figs\bobspreads_$tsfx.emf"
  graph export $a98, replace
*
twoway (tsline $retaillist, yaxis(1)) (tsline obci, yaxis(2)) if tin($t0,$tn), ///
  title("Retail price spreads and petroleum RIN obligation") ///
  ytitle("spreads: $ per gallon") xtitle("RIN obligation: $ per gallon") ///
  subtitle("Spreads, left scale; RIN obligation, right scale")
  global a98 "figs\retailspreads_$tsfx.emf"
  graph export $a98, replace
tsset time
*
*------------------------------------------------------*
*    Individual spreads: scatterplots, time series plots, rolling regressions
*------------------------------------------------------*
gen d5d6c5 = d6c5 - L5.d6c5
gen d10d6c5 = d6c5 - L10.d6c5
*
global gy   "dieselgu_jetgu" 
 global gyf "Diesel Gulf-Jet Fuel Gulf Spread"
 do rin_passthru_figs_wp_core
*
global gy   "dieselny_dieselrot" 
 global gyf "Diesel NYH-Diesel Rotterdam Spread"
 do rin_passthru_figs_wp_core
*
global gy   "dieselgu_dieselrot" 
 global gyf "Diesel Gulf-Diesel Rotterdam Spread"
 do rin_passthru_figs_wp_core
*
global gy   "rbobnyf_ebob"
 global gyf "RBOB NYH Futures-EBOB Spread"
 do rin_passthru_figs_wp_core
*
global gy   "rbobnyf_brent"
 global gyf "RBOB NYH Futures-Brent Spread"
 do rin_passthru_figs_wp_core
*
global gy   "rbobla_brent" 
 global gyf "RBOB LA-Brent Spread"
 do rin_passthru_figs_wp_core
*
global gy   "e85_e10" 
 global gyf "E85-E10 Spread"
 do rin_passthru_figs_wp_core
*
global gy   "e10b"
 global gyf "E10 Price"
 do rin_passthru_figs_wp_core
*
*------------------------------------------------------*
log close
end
