clear
cap log close
cap program drop _all
log using rin_passthru_7c.txt, text replace
set scheme s1color
set more off
************************************************************************************
* rin_passthru_levels_wp.do       This version: 7/1/15
*
* RIN-fuel price analysis for Knittel-Meiselman-Stock paper
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup_wp
local runsfx "_vwp_$dset"
*
*------------------------------------------------------*
*         SAMPLE
* Sample $t0 - $tn
global t0 "01Jan2013"
global t1 "31Dec2013"
global t2 "01Jan2014"
global tn "10Mar2015"
*
local tsfx _$t0-$tn
local tabname "\diesel_bob_sprds_coint"
*------------------------------------------------------*
*
*------------------------------------------------------*
*         LEVELS REGRESSIONS DAILY DATA
*------------------------------------------------------*
* specify lags for NW SEs 
local nwl = 30
*
* Unit root tests - RIN prices
foreach y in d6c d5c d4c {
 dfgls `y'i if (date>=td($t0))*(date<=td($tn)), maxlag(6) notrend ers
  local ylag = r(maiclag)
 dfuller `y'i if (date>=td($t0))*(date<=td($tn)), lags(`ylag')
}
*
* Also consider 4-week lag levels regressions for E85
gen e85_e10l4i = e85_e10i
gen e85_e10l4ti = L20.e85_e10ti
*
global outxls "$tablepath`tabname'`runsfx'`tsfx'.xls" 
cap erase $outxls 
sca srow = 1
*
foreach y in $diesel_sprdvars $bob_sprdvars e85_e10 e85_e10l4 {
*
dis "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
dis "     `y'    $outxls
dis "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
*
* DOLS and OLS, with SA and without, full and subsample
*
 newey `y'i `y'ti $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwl') force
   sca b_dols1 = _b[`y'ti]
   sca se_dols1 = _se[`y'ti]
*
 newey `y'i `y'ti L(-5/5).D.`y'ti $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwl') force
   sca b_dols2 = _b[`y'ti]
   sca se_dols2 = _se[`y'ti]
  testparm $savars
   sca fsa = r(F)
   sca psa = r(p)
*
 newey `y'i `y'ti $savars s5 c5 s6 c6 if (date>=td($t0))*(date<=td($tn)), lag(`nwl') force
   sca b_dols3 = _b[`y'ti]
   sca se_dols3 = _se[`y'ti]
*
 newey `y'i `y'ti if (date>=td($t0))*(date<=td($tn)), lag(`nwl') force
   sca b_dols4 = _b[`y'ti]
   sca se_dols4 = _se[`y'ti]
*
 newey `y'i `y'ti if (date>=td($t0))*(date<=td($t1)), lag(`nwl') force
  sca b_dols5 = _b[`y'ti]
  sca se_dols5 = _se[`y'ti]
*
 newey `y'i `y'ti if (date>=td($t2))*(date<=td($tn)), lag(`nwl') force
  sca b_dols6 = _b[`y'ti]
  sca se_dols6 = _se[`y'ti]
*
dis "--- Unit root tests, full-sample ---"
 dfgls `y'i if (date>=td($t0))*(date<=td($tn)), maxlag(6) notrend ers
  local ylag = r(maiclag)
  local zzrowylag = 6 - `ylag' + 1
  dis " r(maiclag) = " `ylag'
  mat zz = r(results)
  mat list zz
  sca dfgls = zz[`zzrowylag',5]
  dis " r(maiclag) = " `ylag' "   zzrowlag =" `zzrowylag' "   dfgls = " dfgls
 dfuller `y'i if (date>=td($t0))*(date<=td($tn)), lags(`ylag')
  sca adf = r(Zt)
  sca adfp = r(p)
*
* Engle-Granger cointgegration test
 egranger `y'i `y'ti if (date>=td($t0))*(date<=td($tn)), regress lags(6) 
  sca egadf = e(Zt)
*
*output to excel
 local r = srow
/*
 * unformatted
 putexcel A`r'=("`y'") B`r'=(b_dols1) C`r'=(se_dols1) D`r'=(b_dols2) E`r'=(se_dols2) ///
          F`r'=(b_ols3) G`r'=(se_ols3) H`r'=(b_dols4) I`r'=(se_dols4) J`r'=(b_dols5) K`r'=(se_dols5) ///
          L`r'=(fsa) M`r'=(psa) N`r'=(dfgls) O`r'=(adf) P`r'=(adfp) Q`r'=(egadf) ///
          using $outxls, modify
*/
 * formatted
forvalues i = 1/6 {
 sca t99 = abs(b_dols`i'/se_dols`i')
 local fb_dols`i' = string(b_dols`i',"%5.3f")
  if t99>=1.645 local fb_dols`i' = string(b_dols`i',"%5.3f") + "*"
  if t99>=1.96  local fb_dols`i' = string(b_dols`i',"%5.3f") + "**"
  if t99>=2.575 local fb_dols`i' = string(b_dols`i',"%5.3f") + "***"
 local fse_dols`i' = "(" + string(se_dols`i',"%5.3f") + ")"
}
 local ffsa = string(fsa,"%5.2f")
 local fpsa = "(" + string(psa,"%5.3f") + ")"
 local fdfgls = string(dfgls,"%5.3f")
  if dfgls<-1.62 local fdfgls = string(dfgls,"%5.3f") + "*"
  if dfgls<-1.95 local fdfgls = string(dfgls,"%5.3f") + "**"
  if dfgls<-2.58 local fdfgls = string(dfgls,"%5.3f") + "***"
 local fadf = string(adf,"%5.3f")
  if adfp<.10 local fadf = string(adf,"%5.3f") + "*"
  if adfp<.05 local fadf = string(adf,"%5.3f") + "**"
  if adfp<.01 local fadf = string(adf,"%5.3f") + "***"
 local fegadf = string(egadf,"%5.3f")
  if egadf<-3.052 local fegadf = string(egadf,"%5.3f") + "*"
  if egadf<-3.347 local fegadf = string(egadf,"%5.3f") + "**"
  if egadf<-3.916 local fegadf = string(egadf,"%5.3f") + "***"
 putexcel A`r'=("`y'") B`r'=("`fb_dols1'") C`r'=("`fse_dols1'") D`r'=("`fb_dols2'") E`r'=("`fse_dols2'") ///
          F`r'=("`fb_dols3'") G`r'=("`fse_dols3'") ///
		  H`r'=("`fb_dols4'") I`r'=("`fse_dols4'") ///
		  J`r'=("`fb_dols5'") K`r'=("`fse_dols5'") L`r'=("`fb_dols6'") M`r'=("`fse_dols6'") ///
		  N`r'=("`ffsa'") O`r'=("`fpsa'") P`r'=("`fdfgls'") Q`r'=("`fadf'") R`r'=("`fegadf'") ///
          using $outxls, modify
 sca srow = srow+1
}
*------------------------------------------------------*
log close
end
