clear
cap log close
cap program drop _all
log using rin_passthru_sem_levels_v2.txt, text replace
set scheme s1color
set more off
************************************************************************************
* rin_passthru_sem_levels.do
* Spencer Smith, Katie Allsop, JS 6/20/2013-7/2/2013, JS 12/7/13,..., 3/3/14
* JS 8/22/14, 3/26/15, 4/1/15, 4/24/15, CK 4/2015, JS 5/15-19/15, 6/21/15 
*
* System estimation of distributed lag dynamics for obligated & non-obligated fuels
* Daily data - se rin_passthru_5.do for documentation
*
* Pooled levels regressions (estimation by constrained OLS or DOLS)
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup
*
*------------------------------------------------------*
*         date concordance
*
* "01Jan2013" 1823
* "01Feb2013" 1844
* "31Dec2013" 2075
* "01Jan2014" 2076
* "10Feb2015" 2354
* "10Mar2015" 2373
*list date if date>=td(01Jan2013)
*------------------------------------------------------*
*
*------------------------------------------------------*
*      LEVELS REGRESSIONS: daily pooled restricted regression 
*------------------------------------------------------*
*
gen xvar1 = obci
gen dxvar1 = D.obci
*
global outxls = "..\Tables\multeqn_levels_v3bbs.xls"
sca splags = 0
sca snw = 30
*
* Initializations
cap erase $outxls
sca srow = 1
forvalues i = 1/8 {
 cap gen y`i'=.
}
*
*  -- Confirm that pooled code replicates STATA, single eqn --
global slabel "Test: dieselgu_jetgui"
replace y1 = dieselgu_jetgui 
sca snv = 1
*
global t0 "01Jan2013"
global tn "10Mar2015"
local nwltst = snw
*
* OLS, seasonals
global intvars $savars 
do rin_newey_multeqn_core
newey dieselgu_jetgui obci $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwltst')
*
* DOLS, seasonals
local nwltst = snw
global intvars "L(-5/5).dxvar1 c1 s1 c2 s2 c3 s3 c4 s4"
do rin_newey_multeqn_core
newey dieselgu_jetgui obci L(-5/5).dxvar1 $savars if (date>=td($t0))*(date<=td($tn)), lag(`nwltst')
*
* OLS, no controls
global intvars ""
do rin_newey_multeqn_core
newey dieselgu_jetgui obci if (date>=td($t0))*(date<=td($tn)), lag(`nwltst')
*
* Re-initializations - don't tabulate previous code testing results
cap erase $outxls
sca srow = 1
*
*------------------------------------------------------*
*     Table 2 pooled levels regressions 
*------------------------------------------------------*
*
* ----- (A) All 6 spreads -------- 
global slabel "BOB+Diesel"
replace y1 = dieselgu_jetgui 
replace y2 = dieselny_dieselroti 
replace y3 = dieselgu_dieselroti 
replace y4 = rbobnyf_ebobi 
replace y5 = rbobnyf_brenti 
replace y6 = rbobla_brenti 
sca snv = 6
*
* (1) OLS, full sample, seasonals
global intvars $savars 
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (2) DOLS, full sample, seasonals
global intvars "L(-5/5).dxvar1 c1 s1 c2 s2 c3 s3 c4 s4"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (3) OLS, full sample, augmented seasonals
global intvars "c1 s1 c2 s2 c3 s3 c4 s4 c5 s5 c6 s6"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (4) OLS, full sample, no controls
global intvars ""
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (5) OLS, 2013, no controls
global intvars ""
global t0 "01Jan2013"
global tn "31Dec2013"
 do rin_newey_multeqn_core
* (6) OLS, 2014-15, no controls
global intvars ""
global t0 "01Jan2014"
global tn "10Mar2015"
 do rin_newey_multeqn_core
*
* ----- (B) Diesel spreads -------- 
global slabel "Diesel"
replace y1 = dieselgu_jetgui 
replace y2 = dieselny_dieselroti 
replace y3 = dieselgu_dieselroti 
sca snv = 3
*
* (1) OLS, full sample, seasonals
global intvars $savars 
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (2) DOLS, full sample, seasonals
global intvars "L(-5/5).dxvar1 c1 s1 c2 s2 c3 s3 c4 s4"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (3) OLS, full sample, augmented seasonals
global intvars "c1 s1 c2 s2 c3 s3 c4 s4 c5 s5 c6 s6"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (4) OLS, full sample, no controls
global intvars ""
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (5) OLS, 2013, no controls
global intvars ""
global t0 "01Jan2013"
global tn "31Dec2013"
 do rin_newey_multeqn_core
* (6) OLS, 2014-15, no controls
global intvars ""
global t0 "01Jan2014"
global tn "10Mar2015"
 do rin_newey_multeqn_core
*
* ----- (C) BOB spreads -------- 
global slabel "BOB"
replace y1 = rbobnyf_ebobi 
replace y2 = rbobnyf_brenti 
replace y3 = rbobla_brenti 
sca snv = 3
*
* (1) OLS, full sample, seasonals
global intvars $savars 
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (2) DOLS, full sample, seasonals
global intvars "L(-5/5).dxvar1 c1 s1 c2 s2 c3 s3 c4 s4"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (3) OLS, full sample, augmented seasonals
global intvars "c1 s1 c2 s2 c3 s3 c4 s4 c5 s5 c6 s6"
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (4) OLS, full sample, no controls
global intvars ""
global t0 "01Jan2013"
global tn "10Mar2015"
 do rin_newey_multeqn_core
* (5) OLS, 2013, no controls
global intvars ""
global t0 "01Jan2013"
global tn "31Dec2013"
 do rin_newey_multeqn_core
* (6) OLS, 2014-15, no controls
global intvars ""
global t0 "01Jan2014"
global tn "10Mar2015"
 do rin_newey_multeqn_core
*
************************************************************************************
log close
end
