clear
cap log close
cap program drop _all
log using rin_passthru_sem_vx.txt, text replace
set scheme s1color
set more off
************************************************************************************
* rin_passthru_sem_wp.do               This version: 7/1/15
*
* RIN-fuel price analysis for Knittel-Meiselman-Stock paper
*
* System estimation of distributed lag dynamics for obligated & non-obligated fuels
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup_wp
local runsfx "_vwp_$dset"
*
*------------------------------------------------------*
*         date concordance
*
* "01Jan2013" 1823
* "01Feb2013" 1844
* "31Dec2013" 2075
* "01Jan2014" 2076
* "10Feb2015" 2354
* "10Mar2015" 2373
*list date if date>=td(01Jan2013)
*------------------------------------------------------*
*
*------------------------------------------------------*
*      REGRESSIONS: daily pooled restricted regression
*------------------------------------------------------*
*
gen xvar1 = D.obci
gen dxvar1 = D.D.obci
*
global outxls = "..\Tables\multeqn`runsfx'.xls"
sca splags = 15
sca snw = 15
*
* Initializations
cap erase $outxls
sca srow = 1
forvalues i = 1/8 {
 cap gen y`i'=.
}
*------------------------------------------------------*
*     Regressions with seasonal adjustment 
*------------------------------------------------------*
global intvars $savars 
*
* ----- (A) All 6 spreads -------- 
global slabel "BOB+Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
replace y4 = D.rbobnyf_ebobi 
replace y5 = D.rbobnyf_brenti 
replace y6 = D.rbobla_brenti 
sca snv = 6
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
* ----- (B) Diesel spreads -------- 
global slabel "Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
* ----- (C) BOB spreads -------- 
global slabel "BOB"
replace y1 = D.rbobnyf_ebobi 
replace y2 = D.rbobnyf_brenti 
replace y3 = D.rbobla_brenti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
*------------------------------------------------------*
*     Regressions with seasonal adjustment and Brent controls
*------------------------------------------------------*
global intvars $savars L(0/5).D.brentei
*
* ----- (A) All 6 spreads -------- 
global slabel "BOB+Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
replace y4 = D.rbobnyf_ebobi 
replace y5 = D.rbobnyf_brenti 
replace y6 = D.rbobla_brenti 
sca snv = 6
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
*
* ----- (B) Diesel spreads -------- 
global slabel "Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
*
* ----- (C) BOB spreads -------- 
global slabel "BOB"
replace y1 = D.rbobnyf_ebobi 
replace y2 = D.rbobnyf_brenti 
replace y3 = D.rbobla_brenti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
*
*------------------------------------------------------*
*     Regressions without seasonal adjustment 
*------------------------------------------------------*
global intvars " "
*
* ----- (A) All 6 spreads -------- 
global slabel "BOB+Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
replace y4 = D.rbobnyf_ebobi 
replace y5 = D.rbobnyf_brenti 
replace y6 = D.rbobla_brenti 
sca snv = 6
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
* ----- (B) Diesel spreads -------- 
global slabel "Diesel"
replace y1 = D.dieselgu_jetgui 
replace y2 = D.dieselny_dieselroti 
replace y3 = D.dieselgu_dieselroti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
* ----- (C) BOB spreads -------- 
global slabel "BOB"
replace y1 = D.rbobnyf_ebobi 
replace y2 = D.rbobnyf_brenti 
replace y3 = D.rbobla_brenti 
sca snv = 3
*
* full sample
global t0 "01Jan2013"
global tn "10Mar2015"
do rin_newey_multeqn_core
* 2013
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
* 2014-2015
global t0 "01Jan2013"
global tn "31Dec2013"
do rin_newey_multeqn_core
*
************************************************************************************
log close
