set more off
***************************************************************
* rin_passthru_var_pooled_core.do
*       JS 5/23,24/15, 6/21/15
*       Constrained VARs for RIN project, RIN obligation ordered first
*       computes IRFs, writes results to excel
*       Constrained estimation for multiple spreads, with all spreads constrained
*       to have same dynamics - these overid constraints are tested
*   Technical notes:
*     -implement as a single VAR with coeff constraints
*       Lag constraints imposed as constraints on underlying reduced form VAR
*       Contemporaneous impact constraint is constraint on B matrix
*     -implement in levels with sum-to-one and sum-to-zero constraints to get Cumulative SIRFs
***************************************************************
* General code for multiple variables and multiple lags
local nv = snv
local nvp1 = `nv'+1
local p = $gp
local pp1 = `p'+1
global vlist "xvar1"
forvalues i = 1/`nv' {
 global vlist $vlist y`i'
}
dis "$vlist"
* VAR zero constraints
constraint drop _all
local cc = 0
forvalues i = 2/`nv' {
 forvalues k = 1/`p' {
  local cc = `cc'+1
  constraint `cc' [xvar1]L`k'.y1 = [xvar1]L`k'.y`i'
 }
} 
forvalues k = 1/`p' {
 forvalues i = 1/`nv' {
  if `i' > 1 {
   local cc = `cc'+1
   constraint `cc' [y1]L`k'.xvar1 = [y`i']L`k'.xvar1
   local cc = `cc'+1
   constraint `cc' [y1]L`k'.y1 = [y`i']L`k'.y`i'
  }
  local ip1 = `i'+1
  forvalues j = `ip1'/`nv' {
   local cc = `cc'+1
   constraint `cc' [y`i']L`k'.y`j' = 0
   local cc = `cc'+1
   constraint `cc' [y`j']L`k'.y`i' = 0
  }
 }
}
if diffs==1 { 
 * sum-to-one and sum-to-zero constraints
 local i = 0
 foreach u in $vlist {
  local i = `i'+1
  local j = 0
  foreach v in $vlist {
   local j = `j'+1
   global cij "[`u']L1.`v'" 
   dis "$cij"
   forvalues k = 2/`pp1' {
    global cijk "+ [`u']L`k'.`v'"
    global cij $cij $cijk 
   }
   dis "$cij"
   local cc = `cc'+1
   if `i'==`j' {
    constraint `cc' $cij = 1
   }
   else {
    constraint `cc' $cij = 0
   }
  }
 }
}
*
constraint list
*
* SVAR contemporaneous constraints
matrix A = I(`nvp1')
matrix B = J(`nvp1',`nvp1',.)
matrix BC = J(`nvp1',`nvp1',.)
forvalues i = 1/`nvp1' {
 local ip1 = `i'+1
 forvalues j = `ip1'/`nvp1' {
  matrix B[`i',`j'] = 0
  matrix BC[`j',1] = 1
 }
}
*matrix B = (.,0,0\.,.,0\.,.,.)
*matrix BC = (.,.,.\1,.,.\1,.,.)
matrix list A
matrix list B
matrix list BC
* Compute var and cumulative SIRFs (achieved by levels with constraints) with unit effect normalization
svar $vlist if (date>=td($t0))*(date<=td($tn)), exog($exvars) lags(1/`pp1') aeq(A) beq(B) bcns(BC) varconstraints(1/`cc') 
  mat ss = e(Sigma)
  mat list ss
  replace xvar1 = xvar1/sqrt(ss[1,1])
  forvalues i = 1/`nv' {
   replace y`i' = y`i'/sqrt(ss[1,1])
  }
svar $vlist if (date>=td($t0))*(date<=td($tn)), exog($exvars) lags(1/`pp1') aeq(A) beq(B) bcns(BC) varconstraints(1/`cc') var
*   irf create set1, set(vartmp1, replace) bsp reps(100) step(15) replace
   irf create set1, set(vartmp1, replace) step(15) replace
   irf table sirf, std noci 
  replace xvar1 = xvar1*sqrt(ss[1,1])
  forvalues i = 1/`nv' {
   replace y`i' = y`i'*sqrt(ss[1,1])
  }
* output to excel
preserve
  use vartmp1.irf, clear
  drop if sirf==.
  local nsq = `nvp1'*`nvp1'
  gen irfsel = ( ((_n-(`nvp1'+1))/`nsq')==int((_n-(`nvp1'+1))/`nsq') )
  keep if irfsel==1
  mkmat sirf, mat(msirf)
  mkmat stdsirf, mat(mstdsirf)
  mat list msirf
  mat list mstdsirf
  *--- output to excel
  local row = srow
  local rp1 = `row'+1
  * Numerical
  putexcel A`row'=("$slabel") B`row'=("$t0") C`row'=("$tn") D`row'=(`nv') E`row'=(`p') F`row'=("$exvars") ///
    G`row'=matrix(msirf') G`rp1'=matrix(mstdsirf') using $outxls, sheet("numerical") modify
  * Text
  putexcel A`row'=("$slabel") B`row'=("$t0") C`row'=("$tn") D`row'=(`nv') E`row'=(`p') F`row'=("$exvars") using $outxls, sheet("text") modify
   mat bb = msirf
   mat ss = mstdsirf
   local mm = rowsof(bb)
   forvalues i = 1/`mm' {
	sca t99 = abs(bb[`i',1]/ss[`i',1])
	local fb = string(bb[`i',1],"%5.3f")
	 if t99>=1.645 local fb=string(bb[`i',1],"%5.3f") + "*"
	 if t99>=1.96  local fb=string(bb[`i',1],"%5.3f") + "**"
	 if t99>=2.575 local fb=string(bb[`i',1],"%5.3f") + "***"
	local fse = "(" + string(ss[`i',1],"%5.3f") + ")"
	local xcol = char(70+`i')
   putexcel `xcol'`row'=("`fb'") `xcol'`rp1'=("`fse'") using $outxls, sheet("text") modify
   }
  sca srow = srow+2
restore
