clear
cap log close
cap program drop _all
log using rin_passthru_var_vxb.txt, text replace
set scheme s1color
set matsize 2000
set more off
************************************************************************************
* rin_passthru_var_wp.do                   This version: 7/1/15
*
* RIN-fuel price analysis for Knittel-Meiselman-Stock paper
* VARs - individual and combined 
*   Warning: pooled vars are very slow (computing IRF SEs)
*
************************************************************************************
*
* Data read and preliminary calculations
do rin_setup_wp
local runsfx "_vwp_$dset"
*
foreach m in r i 5 {
 *gen e10`m' = e10b`m'
 cap drop e10bt`m'
 gen e10bt`m' = d6c`m'
}
*
* ----------------------------------------------------------------------
*   Bivariate VARs and IRFs - Spread by spread 
*     orthogonalized cumulative with RIN price ordered first
* ----------------------------------------------------------------------
*
global outxls = "..\Tables\vars_bivariate_levels`runsfx'.xls"
global gp = 4
*
sca srow = 1
cap erase $outxls
foreach y in $diesel_sprdvars $bob_sprdvars e85_e10 e10b {
 global gy `y'
*
 global t0 "01Jan2013"
 global tn "10Mar2015"
 global exvars "$savars"
  do rin_passthru_var_levels_core
*
 global t0 "01Jan2013"
 global tn "10Mar2015"
 global exvars "$savars L(0/5).D.brentei"
  do rin_passthru_var_levels_core
*
 global t0 "01Jan2013"
 global tn "10Mar2015"
 global exvars " "
  do rin_passthru_var_levels_core
*
 global t0 "01Jan2013"
 global tn "31Dec2013"
 global exvars " "
  do rin_passthru_var_levels_core
*
 global t0 "01Jan2014"
 global tn "10Mar2015"
 global exvars " "
  do rin_passthru_var_levels_core
}
*
*------------------------------------------------------*
* Pooled VARs for multiple spreads
*   Impose all IRFS same across VARS
* snv is number of spreads, gp is number of lags in first differences
* diffs=1 imposes VAR estimation in first differences, else in levels
*------------------------------------------------------*
gen xvar1 = obci
sca diffs=0
global outxls = "..\Tables\vars_pooled_levels`runsfx'.xls"
global gp = 4
*
* Initializations
cap erase $outxls
sca srow = 1
forvalues i = 1/8 {
 cap gen y`i'=.
}
*
* ---- Vars with seasonal controls ----
global exvars "$savars"
*------------------------------------------------------*
*   (A) Diesel spreads 
*------------------------------------------------------*
global slabel "Diesel"
replace xvar1 = obci
replace y1 = dieselgu_jetgui 
replace y2 = dieselny_dieselroti 
replace y3 = dieselgu_dieselroti 
sca snv = 3
*
 * full sample
 global t0 "01Jan2013"
 global tn "10Mar2015"
  do rin_passthru_var_pooled_core
*
*------------------------------------------------------*
*   (B) BOB spreads 
*------------------------------------------------------*
*
global slabel "BOB"
replace xvar1 = obci
replace y1 = rbobnyf_ebobi 
replace y2 = rbobnyf_brenti 
replace y3 = rbobla_brenti 
sca snv = 3
*
 * full sample
 global t0 "01Jan2013"
 global tn "10Mar2015"
  do rin_passthru_var_pooled_core
*
*------------------------------------------------------*
*  (C) All 6 spreads 
*------------------------------------------------------*
global slabel "BOB+Diesel"
replace xvar1 = obci
replace y1 = dieselgu_jetgui 
replace y2 = dieselny_dieselroti 
replace y3 = dieselgu_dieselroti 
replace y4 = rbobnyf_ebobi 
replace y5 = rbobnyf_brenti 
replace y6 = rbobla_brenti 
sca snv = 6
*
 * full sample
 global t0 "01Jan2013"
 global tn "10Mar2015"
  do rin_passthru_var_pooled_core
*
*------------------------------------------------------*
log close





