************************************************************************************
* rin_setup_wp.do
*
* Reads in fuels price data, spreads, transformations, other setup
* Version for working paper replication file 7/1/15
*
************************************************************************************
*PC version and data set
*global dset "abeop"
global dset "be"
*
local dsetsfx "_$dset"
global dsetname "data_fuels\data_fuels`dsetsfx'_daily.dta"
use $dsetname
dis "$dsetname"
global figpath = "figs\\"
global tablepath "..\Tables\"
/*
*Mac version
use "data_fuels/data_fuels_`dset'_daily.dta"
sca figpath = "fig/"
global tablepath "../Tables/"
*/
local sfx "_vwp`dsetsfx'"
desc
tsset date
*
*--------------------------------------------------------------------*
*  Housekeeping: dates, drop holidays, create seasonal and weekday variables
*--------------------------------------------------------------------*
* collapse to business days (days that NYMEX is open so RBOB futures are nonmissing)
list date if nyhrbobfute==.
drop if nyhrbobfute==.
drop time
gen time = _n
tsset time
*
* seasonals
gen doy366 = doy(date)
forvalues i = 1/6 {
 gen s`i' = sin(`i'*2*_pi*doy366/366)
 gen c`i' = cos(`i'*2*_pi*doy366/366)
}
global savars "s1 c1 s2 c2 s3 c3 s4 c4 "
*
* weekday dummies
forvalues i = 1/5 {
 gen w`i' = (weekday==`i')
}
global wvars "w1 w2 w3 w4"
*--------------------------------------------------------------------*
global t1 "01Jan2012"
global t2 "01Sep2012"
global t3 "01Jan2013"
global t5 "01Mar2013"
global t8 "01Jan2014"
*
*--------------------------------------------------------------------*
*  data transformations
*--------------------------------------------------------------------*
*  Methods for handling missing obs and smoothing:
*      m = "r" no interpolation or smoothing (raw data with missing values)
*      m = "i" impute today's price to be price on most recent trading day
*      m = "5" 5-day moving average
*--------------------------------------------------------------------*
gen brentgale = brente/42
gen brentgalei = brentei/42
gen brentgale5 = brente5/42
* Need to create raw data variables with "m" suffix
global basefuels nyhrbobfute spotrbobb nyhcbobe gulfcbobe larbobe nyhheatinge ///
                  nyhultralowdiesele gulfultralowdiesele laultralowdiesele gulfjete nyhheatingfute ///
                  e100b e10b e85b obc brente brentgale eurobob eurodiesel d4c d5c d6c ob13c 
foreach x of varlist $basefuels {
 gen `x'r = `x'
}
* --- wholesale EU-US spreads -----
foreach m in r i 5 {
 gen dieselgu_jetgu`m' = gulfultralowdiesele`m' - gulfjete`m'
 gen dieselny_dieselrot`m' = nyhultralowdiesele`m' - eurodiesel`m'
 gen dieselgu_dieselrot`m'  = gulfultralowdiesele`m' - eurodiesel`m'
 gen rbobnyf_ebob`m' =  nyhrbobfute`m' -  eurobob`m'
 gen rbobnyf_brent`m' =  nyhrbobfute`m' -  brentgale`m'
 gen rbobla_brent`m' =  larbobe`m' -  brentgale`m'
 * --- retail and retail-wholesale US spreads -----
 gen e85_e10`m' = e85b`m' - e10b`m'
}
*
global diesel_sprdvars dieselgu_jetgu dieselny_dieselrot dieselgu_dieselrot 
global bob_sprdvars rbobnyf_ebob rbobnyf_brent rbobla_brent 
global retail_vars e85_e10 e10
*
*-------------------------------------------------*
* Theory predicted ("t") spreads (static equilibrium competitive pricing)
*-------------------------------------------------*
*
* Price of RIN bundle 
local rinbun "obc"
foreach m in r i 5 {
 gen pbun`m' = `rinbun'`m'
 gen d5pbun`m' = `rinbun'`m' - L5.`rinbun'`m'
}
*
* Retail fuel obligations 
foreach m in r i 5 {
 * Predicted wholesale spread obligations
 gen dieselgu_jetgut`m' = pbun`m' 
 gen dieselny_dieselrott`m' = pbun`m'
 gen dieselgu_dieselrott`m' = pbun`m'
 gen rbobnyf_ebobt`m' = pbun`m'
 gen rbobnyf_brentt`m' =  pbun`m'
 gen rbobla_brentt`m' =  pbun`m'
 * Predicted retail spread obligations
 gen e10bt`m' = -.1*d6c`m' + .9*pbun`m'
 gen e85bt`m' = -.74*d6c`m' + .26*pbun`m'
 gen e85_e10t`m' = e85bt`m' - e10bt`m'
}
